@@ -195,7 +195,11 @@ class ShotDetector():
         self.background_look_back_frames = params.get('background_look_back_frames', 20)
         self.is_debug = params.get('is_debug', False)
         self.do_not_override_res = params.get('do_not_override_res', False)
-        self.csv_path = f"{self.path_to_data_folder}/{self.name}_audio_shot_detection.csv"
+        
+        postfix = params.get('postfix', None)
+        if postfix is None:
+            postfix = ''
+        self.csv_path = f"{self.path_to_data_folder}/{self.name}_audio_shot_detection{postfix}.csv"
         self.max_fnum = None
         if params.get('max_sec', None):
             self.max_fnum = int(params['max_sec'] * self.fps)
@@ -580,17 +584,19 @@ async def prepare_video(video_url, path_to_vid=None, path_to_data_folder=PATH_TO
     }
 
 
-async def process_video(common_params, video_url, path_to_video=None, path_to_data_folder=PATH_TO_DATA_FOLDER):
+async def process_video(common_params, video_url, path_to_video=None, path_to_data_folder=PATH_TO_DATA_FOLDER, postfix=None):
     vid_params = await prepare_video(video_url, path_to_vid=path_to_video, path_to_data_folder=path_to_data_folder)
     vid_params = {
         **common_params,
         **vid_params
     }
-    shot_detector = ShotDetector(**vid_params)
+    shot_detector = ShotDetector(**vid_params, postfix=postfix)
     shot_detector.detect()
     shot_detector.show()
 
-    return f'{path_to_data_folder}/{vid_params["name"]}_audio_shot_detection.csv'
+    if postfix is None:
+        postfix = ''
+    return f'{path_to_data_folder}/{vid_params["name"]}_audio_shot_detection{postfix}.csv'
 
 
 async def main(path_to_hoop_model, path_to_ball_model, models_bucket, min_score, local_vid_path, video_url, path_to_data_folder, visualize, is_notebook):
